pub struct QueryAnswerPair<U, const WIDTH: usize> {
pub input: [U; WIDTH],
pub output: [U; WIDTH],
}Expand description
One evaluation of the permutation: the state it read and the state it wrote. Over wires in a relation, over values in a witness.
Fields
input: [U; WIDTH]output: [U; WIDTH]Implementations
Sourceimpl<U, const WIDTH: usize> QueryAnswerPair<U, WIDTH>
impl<U, const WIDTH: usize> QueryAnswerPair<U, WIDTH>
pub const fn new(input: [U; WIDTH], output: [U; WIDTH]) -> Self